.. Fuisce documentation master file, created by
   sphinx-quickstart on Sat May  6 11:00:00 2023.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Fuisce
======

Database management and testing for SQLAlchemy-based Flask apps.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   api/modules

.. include:: README.md
   :parser: myst_parser.sphinx_


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
